@@ -11,7 +11,7 @@ from iocingestor import config, exceptions, state
 from iocingestor.artifacts import Artifact
 from iocingestor.whitelists import Whitelist
 
-__version__ = "0.1.0"
+__version__ = "0.2.0"
 
 
 class Ingestor:
@@ -33,7 +33,11 @@ class Ingestor:
 
         # Configure logging with optional notifiers.
         logger.configure(**self.config.logging())
-        logger.level("NOTIFY", no=35, color="<yellow>", icon="\U0001F514")
+        try:
+            logger.level("NOTIFY", no=35, color="<yellow>", icon="\U0001F514")
+        except TypeError:
+            # logger raises TypeError if NOTIFY is already defined
+            pass
 
         logger.debug("Log handler reconfigured")
 
@@ -49,7 +53,7 @@ class Ingestor:
         try:
             logger.debug(f"Opening state database '{self.config.state_path()}'")
             self.statedb = state.State(self.config.state_path())
-        except (OSError, IOError, exceptions.IngestorError):
+        except (OSError, exceptions.IngestorError):
             # Error loading state DB.
             logger.exception("Error reading state database")
             sys.exit(1)
